## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  message = FALSE,
  warning = FALSE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
library(SpatialFeatures)
library(MoleculeExperiment)
library(SingleCellExperiment)
library(ggplot2)
library(dplyr)

## -----------------------------------------------------------------------------
repoDir <- system.file("extdata", package = "MoleculeExperiment")
repoDir <- paste0(repoDir, "/xenium_V1_FF_Mouse_Brain")

me <- readXenium(repoDir, keepCols = "essential")
me

## -----------------------------------------------------------------------------
se = spatialFeatures(me)
se

## -----------------------------------------------------------------------------
se = spatialFeatures(me, includeCounts = TRUE, concatenateFeatures = FALSE)
se

## -----------------------------------------------------------------------------
me <- SpatialFeatures::loadBoundaries(me)
me

## -----------------------------------------------------------------------------
ggplot_me() +
  # add molecule points and colour by feature name
  geom_point_me(me, byColour = "feature_id", size = 0.1) +
  # add nuclei segments and colour the border with red
  geom_polygon_me(me, assayName = "subsector", fill = NA, colour = "red") +
  # add cell segments and colour by cell id
  geom_polygon_me(me, byFill = "segment_id", colour = "black", alpha = 0.1) +
  # zoom in to selected patch area
  coord_cartesian(xlim = c(4875, 4950), ylim = c(6385, 6455))

ggplot_me() +
  # add molecule points and colour by feature name
  geom_point_me(me, byColour = "feature_id", size = 0.1) +
  # add nuclei segments and colour the border with red
  geom_polygon_me(me, assayName = "subconcentric", fill = NA, colour = "red") +
  # add cell segments and colour by cell id
  geom_polygon_me(me, byFill = "segment_id", colour = "black", alpha = 0.1) +
  # zoom in to selected patch area
  coord_cartesian(xlim = c(4875, 4950), ylim = c(6385, 6455))

ggplot_me() +
  # add molecule points and colour by feature name
  geom_point_me(me, byColour = "feature_id", size = 0.1) +
  # add nuclei segments and colour the border with red
  geom_polygon_me(me, assayName = "supersector", fill = NA, colour = "blue") +
  # add cell segments and colour by cell id
  geom_polygon_me(me, byFill = "segment_id", colour = "black", alpha = 0.1) +
  # zoom in to selected patch area
  coord_cartesian(xlim = c(4875, 4950), ylim = c(6385, 6455))

ggplot_me() +
  # add molecule points and colour by feature name
  geom_point_me(me, byColour = "feature_id", size = 0.1) +
  # add nuclei segments and colour the border with red
  geom_polygon_me(me, assayName = "superconcentric", fill = NA, colour = "blue") +
  # add cell segments and colour by cell id
  geom_polygon_me(me, byFill = "segment_id", colour = "black", alpha = 0.1) +
  # zoom in to selected patch area
  coord_cartesian(xlim = c(4875, 4950), ylim = c(6385, 6455))

## -----------------------------------------------------------------------------
ent = SpatialFeatures::EntropyMatrix(me, c("subsector", "subconcentric", "supersector", "superconcentric"), nCores = 1)
lapply(ent, head, n = 4)

## -----------------------------------------------------------------------------
se = SpatialFeatures::EntropySingleCellExperiment(ent, me)
se

## -----------------------------------------------------------------------------
se = EntropySingleCellExperiment(ent, me, includeCounts = TRUE)
se

## -----------------------------------------------------------------------------
se
colData(se)
rowData(se)

## -----------------------------------------------------------------------------
sessionInfo()

